@@ -1,6 +1,13 @@
 """Example implementation of a rule requiring tasks to have tags set."""
+from typing import TYPE_CHECKING, Any, Dict, Union
+
 from ansiblelint.rules import AnsibleLintRule
 
+if TYPE_CHECKING:
+    from typing import Optional
+
+    from ansiblelint.file_utils import Lintable
+
 
 class TaskHasTag(AnsibleLintRule):
     """Tasks must have tag."""
@@ -10,12 +17,10 @@ class TaskHasTag(AnsibleLintRule):
     description = 'Tasks must have tag'
     tags = ['productivity', 'tags']
 
-    def matchtask(self, file, task):
+    def matchtask(
+        self, task: Dict[str, Any], file: 'Optional[Lintable]' = None
+    ) -> Union[bool, str]:
         """Task matching method."""
-        # The meta files don't have tags
-        if file['type'] in ["meta", "playbooks"]:
-            return False
-
         if isinstance(task, str):
             return False
 
