@@ -10,6 +10,13 @@ PASS_WHEN = '''
   debug:
     msg: test
   when: my_var
+
+- name: another example task
+  debug:
+    msg: test
+  when:
+    - 1 + 1 == 2
+    - true
 '''
 
 PASS_WHEN_NOT_FALSE = '''
@@ -38,6 +45,12 @@ FAIL_LITERAL_FALSE = '''
   debug:
     msg: test
   when: my_var == false
+
+- name: another example task
+  debug:
+    msg: test
+  when:
+    - my_var == false
 '''
 
 
@@ -45,25 +58,25 @@ class TestComparisonToLiteralBoolRule(unittest.TestCase):
     collection = RulesCollection()
     collection.register(ComparisonToLiteralBoolRule())
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.runner = RunFromText(self.collection)
 
-    def test_when(self):
+    def test_when(self) -> None:
         results = self.runner.run_role_tasks_main(PASS_WHEN)
         self.assertEqual(0, len(results))
 
-    def test_when_not_false(self):
+    def test_when_not_false(self) -> None:
         results = self.runner.run_role_tasks_main(PASS_WHEN_NOT_FALSE)
         self.assertEqual(0, len(results))
 
-    def test_when_not_null(self):
+    def test_when_not_null(self) -> None:
         results = self.runner.run_role_tasks_main(PASS_WHEN_NOT_NULL)
         self.assertEqual(0, len(results))
 
-    def test_literal_true(self):
+    def test_literal_true(self) -> None:
         results = self.runner.run_role_tasks_main(FAIL_LITERAL_TRUE)
         self.assertEqual(1, len(results))
 
-    def test_literal_false(self):
+    def test_literal_false(self) -> None:
         results = self.runner.run_role_tasks_main(FAIL_LITERAL_FALSE)
-        self.assertEqual(1, len(results))
+        assert len(results) == 2, results
