@@ -60,35 +60,29 @@ class TestMetaMainHasInfo(unittest.TestCase):
     collection = RulesCollection()
     collection.register(MetaMainHasInfoRule())
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.runner = RunFromText(self.collection)
 
-    def test_no_galaxy_info(self):
+    def test_no_galaxy_info(self) -> None:
         results = self.runner.run_role_meta_main(NO_GALAXY_INFO)
         assert len(results) == 1
-        self.assertIn("No 'galaxy_info' found",
-                      str(results))
+        self.assertIn("No 'galaxy_info' found", str(results))
 
-    def test_missing_info(self):
+    def test_missing_info(self) -> None:
         results = self.runner.run_role_meta_main(MISSING_INFO)
         assert len(results) == 3
-        self.assertIn("Role info should contain author",
-                      str(results))
-        self.assertIn("Role info should contain min_ansible_version",
-                      str(results))
-        self.assertIn("Platform should contain name",
-                      str(results))
+        self.assertIn("Role info should contain author", str(results))
+        self.assertIn("Role info should contain min_ansible_version", str(results))
+        self.assertIn("Platform should contain name", str(results))
 
-    def test_bad_types(self):
+    def test_bad_types(self) -> None:
         results = self.runner.run_role_meta_main(BAD_TYPES)
         assert len(results) == 3
         self.assertIn("author should be a string", str(results))
         self.assertIn("description should be a string", str(results))
-        self.assertIn("Platforms should be a list of dictionaries",
-                      str(results))
+        self.assertIn("Platforms should be a list of dictionaries", str(results))
 
-    def test_platform_list_of_str(self):
+    def test_platform_list_of_str(self) -> None:
         results = self.runner.run_role_meta_main(PLATFORMS_LIST_OF_STR)
         assert len(results) == 1
-        self.assertIn("Platforms should be a list of dictionaries",
-                      str(results))
+        self.assertIn("Platforms should be a list of dictionaries", str(results))
