@@ -1,5 +1,8 @@
+from pathlib import Path
+
 import pytest
 
+from ansiblelint.rules import RulesCollection
 from ansiblelint.runner import Runner
 
 IMPORTED_PLAYBOOK = '''\
@@ -22,14 +25,16 @@ MAIN_PLAYBOOK = '''\
 
 
 @pytest.fixture
-def playbook(tmp_path):
+def playbook(tmp_path: Path) -> str:
     playbook_path = tmp_path / 'playbook.yml'
     playbook_path.write_text(MAIN_PLAYBOOK)
     (tmp_path / 'imported_playbook.yml').write_text(IMPORTED_PLAYBOOK)
     return str(playbook_path)
 
 
-def test_skip_import_playbook(default_rules_collection, playbook):
+def test_skip_import_playbook(
+    default_rules_collection: RulesCollection, playbook: str
+) -> None:
     runner = Runner(playbook, rules=default_rules_collection)
     results = runner.run()
     assert len(results) == 0
