@@ -16,9 +16,9 @@ class TestTaskNoLocalAction(unittest.TestCase):
     collection = RulesCollection()
     collection.register(TaskNoLocalAction())
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.runner = RunFromText(self.collection)
 
-    def test_local_action(self):
+    def test_local_action(self) -> None:
         results = self.runner.run_role_tasks_main(TASK_LOCAL_ACTION)
         self.assertEqual(1, len(results))
